.. py:currentmodule:: lsst.ctrl.bps.htcondor

.. _lsst.ctrl.bps.htcondor:

######################
lsst.ctrl.bps.htcondor
######################

.. Paragraph that describes what this Python module does and links to related modules and frameworks.

.. _lsst.ctrl.bps.htcondor-changes:

Changes
=======

.. toctree::
  :maxdepth: 1

  CHANGES.rst

.. _lsst.ctrl.bps.htcondor-using:

Using lsst.ctrl.bps.htcondor
============================

.. toctree::
   :maxdepth: 1

   userguide.rst

.. _lsst.ctrl.bps.htcondor-contributing:

Contributing
============

``lsst.ctrl.bps.htcondor`` is developed at https://github.com/lsst/ctrl_bps_htcondor.
You can find Jira issues for this module under the `ctrl_bps_htcondor <https://jira.lsstcorp.org/issues/?jql=project%20%3D%20DM%20AND%20component%20%3D%20ctrl_bps_htcondor>`_ component.

.. If there are topics related to developing this module (rather than using it), link to this from a toctree placed here.

.. .. toctree::
..    :maxdepth: 1

.. _lsst.ctrl.bps.htcondor-pyapi:

Python API reference
====================

.. automodapi:: lsst.ctrl.bps.htcondor
   :no-main-docstr:
   :no-inheritance-diagram:
